class Player {

float w, h, x, y, vx, vy, 
    accelerationX, accelerationY, //der Spieler beschleunigt während der Bewegung
    speedLimit;

  //-----------------------------world variables-----------------------------------
  float friction, bounce, gravity; // Reibung, Sprungkraft und Schwerkraft werden benötigt, um das Gefühl der Spielwelt zu erzeugen
  boolean pdead; // wenn der Spieler auf den Boden fällt, ändert sich sein Zustand in tot
  boolean pwon; // wenn der Spieler auf die Siegessymbole tritt, ändert sich sein Zustand zu won
  boolean isOnGround; // wird benötigt, damit der Spieler nicht in die Luft springen und auf diese Weise schummeln kann
  float jumpForce; //  ist gegen die Schwerkraft

  float halfWidth, halfHeight; // wird für Kollisionen benötigt
  String collisionSide; //  gibt die Kollisionsseite von Spieler und Plattform zurück => siehe game new

  //-----------------------image variables--------------------------
  int currentFrame; //es gibt 24 Bilder und diese Variable regelt, welches Bild gerade angezeigt wird
  boolean facingRight; //  wenn der Spieler nach rechts schaut - werden Frames für ihn angezeigt, wenn nicht - gibt es Frames für den Spieler, der nach links schaut
  int frameSequence; //Anzahl der Bilder in jeder Sequenz
  int frameOffset; //  das Startbild

  
  Player() {
    w = 130;
    h = 230;
    x = 100 - w/2; //damit der Spieler die Grenzen der Welt nicht verlässt
    y = (gameWorld.y + gameWorld.h/2) - h/2; // der Spieler fällt von oben auf den Bildschirm
    vx = 0; //die Geschwindigkeit zu Beginn ist 0
    vy = 0;
    accelerationX = 0; //Gleiches gilt für die Beschleunigung
    accelerationY = 0;
    speedLimit = 20; // damit sich der Spieler nicht zu schnell bewegen kann
    isOnGround = false; //der Spieler befindet sich in der Luft
    pdead = false; // der Spieler ist weder tot noch gewonnen
    pwon = false;
    jumpForce = -20; // ist negativ, damit die Schwerkraft aufgehoben wird
    //world values
    friction = 1; //  damit es auf den Plattformen nicht zu rutschig wird
    bounce = -0.7; // ebenfalls negativ gegen die Schwerkraft
    gravity = .7; // verleiht dem Spiel mehr Realismus

    halfWidth = w/2; //  wird für Kollisionen benötigt
    halfHeight = h/2;

    collisionSide = ""; //am Anfang gibt es keine Kollisionen
    currentFrame = 0; //die Animation beginnt mit dem Frame 0
    facingRight = true; // der Spieler erscheint mit Blick nach rechts
    frameSequence = 6;//Anzahl der Bilder in jeder Animationssequenz
    frameOffset = 0; //die Animation ist zum Bild 0 versetzt
    
  
    
     
  }
  

  void update() {
    //Start aller Bewegungen mit Reibung bei 1

    if (left && !right) { //  wenn der Spieler nach links geht
      accelerationX = -0.2;
      friction = 1;
      facingRight = false;
    }
    if (right && !left) { // wenn der Spieler nach rechts geht
      accelerationX = 0.3;
      friction = 1;
      facingRight = true;
    }
    if (!left&&!right) { // wenn der Spieler nirgendwo hingeht
      accelerationX = 0;
    }

    if (up && !down && isOnGround) { // wenn der Spieler springt, während er auf dem Boden steht
      //accelerationY = -0.2;
      //friction = 1;
      vy = jumpForce;
      isOnGround = false; //  während der Spieler springt, kann er nicht erneut springen
      //gravity = 0;
      friction = 1;
    }

    if (!up && !down && !left && !right) {   //Entfernen des Impulses führt die Reibung wieder ein
      friction = 0.96; 
      //gravity = 0.3;
    }

//Beschleunigung ändert die Geschwindigkeit
    vx += accelerationX;
    vy += accelerationY;

  //Reibung anwenden
    vx *= friction;

    //Anwendung der Schwerkraft
    vy += gravity;

    //Korrektur für Höchstgeschwindigkeiten
    if (vx > speedLimit) {
      vx = speedLimit;
    }
    if (vx < -speedLimit) {
      vx = -speedLimit;
    }
    //Die Schwerkraft muss die Geschwindigkeit erhöhen
    if (vy > 3 * speedLimit) {
      vy = 3 * speedLimit;
    }
    //Nicht nötig beim Springen
    if (vy < -speedLimit) {
      vy = -speedLimit;
    }

    //Korrekte Mindestgeschwindigkeiten
    if (abs(vx) < 0.2) {
      vx = 0;
    }

    if (abs(vy) < 0.2) {
      vy = 0;
    }

    //Bewege den Spieler
    //x+=vx;
    //y+=vy;
    x = Math.max(0, Math.min(x + vx, gameWorld.w - w)); 
    y = Math.max(0, Math.min(y + vy, gameWorld.h - h));

    checkBoundaries(); //  der Spieler kann die Spielwelt nicht verlassen
  }
  void checkPlatforms() {
    //Aktualisierung für Plattformkollisionen
    if (collisionSide == "bottom" && vy >= 0) {
      if (vy < 1) {
        isOnGround = true;
        vy = 0;
      } else {
        //reduzierter Abprall für Bodenabprall
        vy *= bounce/2;
      }
      // Spieler kann sich nicht bewegen, wenn er mit Plattformen kollidiert
    } else if (collisionSide == "top" && vy <= 0) {
      vy = 0;
    } else if (collisionSide == "right" && vx >= 0) {
      vx = 0;
    } else if (collisionSide == "left" && vx <= 0) {
      vx = 0;
    }
    if (collisionSide != "bottom" && vy > 0) {
      isOnGround = false; // wenn der Spieler nicht mit einer Plattform am Boden kollidiert, bedeutet das, dass er sich in der Luft befindet
    }
  }

  void checkBoundaries() {
   //Überprüfung der Spielweltgrenzen
    //Links
    if (x <= 0) {
      vx *= bounce;
   
      facingRight = !facingRight;
    }
    // rechts
    if (x >= gameWorld.w - w) {
      vx *= bounce;
      facingRight = !facingRight;
    }
    //oben
    if (y <= 0) {
      vy *= bounce;
      y = 0;
    }
    if (y >= gameWorld.h - h) {
      if (vy < 1) {
        isOnGround = true;
        vy = 0;
      } else {
        //reduzierter Abprall für Bodenabprall
        vy *= bounce/2;
      }
      y = height - h;
    }
  }



  void display1() { // Anzeige des Players
    noStroke();
    fill(0, 255, 0, 0);
    rect(x, y, w, h); //der Spieler ist ein Rechteck, damit wir die Kollision leicht sehen können
    if (facingRight) {
      if (abs(vx) > 0) { // Animation ändert sich
        image(spriteImages[currentFrame+0], x-10, y, 160, 240);
      } else {
        image(spriteImages[currentFrame+12], x-10, y, 160, 240);
      }
    } else {
      if (abs(vx) > 0) {
        image(spriteImages[currentFrame+6], x-10,y, 160, 240);
      } else {
        image(spriteImages[currentFrame+18], x-10, y, 160, 240);
      }
    }
    if (isOnGround) { // die Bilder ändern sich, wenn der Spieler auf dem Boden steht
      currentFrame = (currentFrame + 1)%frameSequence;
    } else {
      currentFrame = 0;
    }
  }
 void reset(){ // wenn das Spiel erneut abgespielt wird, kehrt der Spieler an seine ursprüngliche Position zurück
   x = 100 - w/2;
    y = (gameWorld.y + gameWorld.h/2) - h/2;
 }
 
}
